==> open-cluster-management-discovery-model-6.5.1-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveredClusterListFluent.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DiscoveredClusterListFluent<A extends DiscoveredClusterListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,DiscoveredCluster item);
  public A setToItems(Integer index,DiscoveredCluster item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.discovery.v1alpha1.DiscoveredCluster... items);
  public A addAllToItems(Collection<DiscoveredCluster> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.discovery.v1alpha1.DiscoveredCluster... items);
  public A removeAllFromItems(Collection<DiscoveredCluster> items);
  public A removeMatchingFromItems(Predicate<DiscoveredClusterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DiscoveredCluster> getItems();
  public List<DiscoveredCluster> buildItems();
  public DiscoveredCluster buildItem(Integer index);
  public DiscoveredCluster buildFirstItem();
  public DiscoveredCluster buildLastItem();
  public DiscoveredCluster buildMatchingItem(Predicate<DiscoveredClusterBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DiscoveredClusterBuilder> predicate);
  public A withItems(List<DiscoveredCluster> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.discovery.v1alpha1.DiscoveredCluster... items);
  public Boolean hasItems();
  public DiscoveredClusterListFluent.ItemsNested<A> addNewItem();
  public DiscoveredClusterListFluent.ItemsNested<A> addNewItemLike(DiscoveredCluster item);
  public DiscoveredClusterListFluent.ItemsNested<A> setNewItemLike(Integer index,DiscoveredCluster item);
  public DiscoveredClusterListFluent.ItemsNested<A> editItem(Integer index);
  public DiscoveredClusterListFluent.ItemsNested<A> editFirstItem();
  public DiscoveredClusterListFluent.ItemsNested<A> editLastItem();
  public DiscoveredClusterListFluent.ItemsNested<A> editMatchingItem(Predicate<DiscoveredClusterBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,DiscoveredClusterFluent<DiscoveredClusterListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-discovery-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveredClusterListFluent.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DiscoveredClusterListFluent<A extends DiscoveredClusterListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,DiscoveredCluster item);
  public A setToItems(int index,DiscoveredCluster item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.discovery.v1alpha1.DiscoveredCluster... items);
  public A addAllToItems(Collection<DiscoveredCluster> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.discovery.v1alpha1.DiscoveredCluster... items);
  public A removeAllFromItems(Collection<DiscoveredCluster> items);
  public A removeMatchingFromItems(Predicate<DiscoveredClusterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DiscoveredCluster> getItems();
  public List<DiscoveredCluster> buildItems();
  public DiscoveredCluster buildItem(int index);
  public DiscoveredCluster buildFirstItem();
  public DiscoveredCluster buildLastItem();
  public DiscoveredCluster buildMatchingItem(Predicate<DiscoveredClusterBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DiscoveredClusterBuilder> predicate);
  public A withItems(List<DiscoveredCluster> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.discovery.v1alpha1.DiscoveredCluster... items);
  public Boolean hasItems();
  public DiscoveredClusterListFluent.ItemsNested<A> addNewItem();
  public DiscoveredClusterListFluent.ItemsNested<A> addNewItemLike(DiscoveredCluster item);
  public DiscoveredClusterListFluent.ItemsNested<A> setNewItemLike(int index,DiscoveredCluster item);
  public DiscoveredClusterListFluent.ItemsNested<A> editItem(int index);
  public DiscoveredClusterListFluent.ItemsNested<A> editFirstItem();
  public DiscoveredClusterListFluent.ItemsNested<A> editLastItem();
  public DiscoveredClusterListFluent.ItemsNested<A> editMatchingItem(Predicate<DiscoveredClusterBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,DiscoveredClusterFluent<DiscoveredClusterListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
